<?php
/**
 *
 * @file : jquery_twitter_search_admin.inc
 * 
 * This file contains administration functions 
 * and functionality implementation.
 * 
 */

function _jquery_twitter_search_admin_page() {
  $build['add_block'] = "<div>" . l(t('Add block'), 'admin/config/jquery-twitter-search/add-block') . "</div>";
  
  $header = array();
  $header[] = array('data' => t('Block title'), 'field' => 'title', 'sort' => 'asc');
  $header[] = array('data' => t('Operations'));
  
  $query = db_select('jquery_twitter_search')->extend('PagerDefault')->extend('TableSort');
  $result = $query->fields('jquery_twitter_search')->orderByHeader($header)->limit(50)->execute();
  
  $rows = array();
  
  foreach ($result as $data) {
    
    $row = array();
    $row['data']['title'] = check_plain($data->title);
    
    $operations = array();
    $operations['edit'] = array(
      'title' => t('edit'),
      'href' => "admin/config/jquery-twitter-search/settings/edit/$data->delta",
      //'query' => $destination,
    );
    $operations['delete'] = array(
      'title' => t('delete'),
      'href' => "admin/config/jquery-twitter-search/del/$data->delta",
      //'query' => $destination,
    );
    
    $row['data']['operations'] = array(
      'data' => array(
        '#theme' => 'links',
        '#links' => $operations,
        '#attributes' => array('class' => array('links', 'inline', 'nowrap')),
      ),
    );
    
    $rows[] = $row;
  }
  
  $build['path_table'] = array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => $rows,
    '#empty' => t('No Twitter search block available. <a href="@link">Add block</a>.', array('@link' => url('admin/config/jquery-twitter-search/settings/edit'))),
  );
  $build['path_pager'] = array('#theme' => 'pager');

  return $build;
}

/**
 * jquery twitter search block creation form.
 * 
 * @param $delta
 *   The id of the block.
 * 
 * @return the form array structre.
 */
function _jquery_twitter_search_admin_form($delta = NULL) {
  $form = array();
  
  if (arg(5)) {
    $block = _jquery_twitter_search_get_block_info(arg(5));
    $options = unserialize($block->options);
  }
  
  $form['jqueryts_title'] = array(
    '#type' => 'textfield',
    '#title' => 'Block Title',
    '#description' => t('Block title.'),
    '#required' => TRUE,
    '#default_value' => (isset($block)) ? $block->title : '' ,
  );
  
  $form['jqueryts_trend'] = array(
    '#type' => 'textfield',
    '#title' => 'Term',
    '#required' => TRUE,
    '#description' => t('Term to search for.'),
    '#default_value' => (isset($options)) ? $options['jqueryts_trend'] : '' ,
  );
  
  $form['jqueryts_animeout'] = array(
    '#type' => 'textfield',
    '#title' => 'AnimeOut',
    '#description' => t('Animation option.'),
    '#default_value' => (isset($options)) ? $options['jqueryts_animeout'] : '' ,
  );
  
  $form['jqueryts_avatar'] = array(
    '#type' => 'checkbox',
    '#title' => 'Use avatar',
    '#description' => t('to Indecate Using Avatar or not.'),
    '#default_value' => (isset($options)) ? $options['jqueryts_avatar'] : '' ,
  );
  
  $form['jqueryts_bird'] = array(
    '#type' => 'checkbox',
    '#title' => 'Use Bird image',
    '#description' => t('to Indecate the border color.'),
    '#default_value' => (isset($options)) ? $options['jqueryts_bird'] : '' ,
  );
  
  $form['jqueryts_colorexterior'] = array(
    '#type' => 'textfield',
    '#title' => '',
    '#description' => t('to Indecate Using Avatar or not.'),
    '#default_value' => (isset($options)) ? $options['jqueryts_colorexterior'] : '' ,
  );
  
  $form['jqueryts_colorinterior'] = array(
    '#type' => 'textfield',
    '#title' => '',
    '#description' => t('to Indecate the background color.'),
    '#default_value' => (isset($options)) ? $options['jqueryts_colorinterior'] : '' ,
  );
  
  $form['jqueryts_pause'] = array(
    '#type' => 'checkbox',
    '#title' => 'Pause',
    '#default_value' => (isset($options)) ? $options['jqueryts_pause'] : '' ,
  );
  
  $form['jqueryts_time'] = array(
    '#type' => 'checkbox',
    '#title' => 'Time',
    '#default_value' => (isset($options)) ? $options['jqueryts_time'] : '' ,
  );
  
  $form['jqueryts_timeout'] = array(
    '#type' => 'textfield',
    '#title' => 'Time',
    '#default_value' => (isset($options)) ? $options['jqueryts_timeout'] : '' ,
  );
  
  $form['block_delta'] = array(
    '#type' => 'hidden',
    '#value' => (isset($block->delta)) ? $block->delta : '',
  );
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Submit',
  );
  
  return $form;
}

/**
 *  block creation form handler.
 */
function _jquery_twitter_search_admin_form_submit($form, &$form_state) {
  foreach ($form_state['values'] as $key => $value) {
    if (preg_match('/jqueryts_/', $key) && $key != 'jqueryts_title') {
      $settings[$key] = $form_state['values'][$key];
    }
  }
  
  
  $fields = array(
    'title' => $form_state['values']['jqueryts_title'],
    'options' => serialize($settings),
  );
  
  if ($form_state['values']['block_delta']) {
    db_update('jquery_twitter_search')->fields($fields)->condition('delta', $form_state['values']['block_delta'])->execute();
  } 
  else {
    db_insert('jquery_twitter_search')->fields($fields)->execute();
  }
  
  drupal_set_message(t('Block :block_title have been saved.', array(':block_title' => check_plain($form_state['values']['jqueryts_title']))));
  drupal_goto('admin/config/jquery-twitter-search/settings');
  
}

/**
 * delete jquery twitter search block from jquery_twitter_search table.
 * 
 * @param $delta
 *   the id of the block.
 */
function _jquery_twitter_search_admin_del_block($delta = NULL) {
  if ($delta) { 
    $deleted = db_delete('jquery_twitter_search')->condition('delta', $delta)->execute();
    $message = t('Block has been deleted.');
  } 
  else {
    $message = t('Wrong block.');
  }
  drupal_set_message(check_plain($message));
  drupal_goto('admin/config/jquery-twitter-search/settings');
}